@@ -9,17 +9,19 @@ require Exporter;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 @ISA = qw(Exporter);
-@EXPORT_OK = qw(ExcelFmt LocaltimeExcel ExcelLocaltime);
-$VERSION=0.05;
+@EXPORT_OK = qw(ExcelFmt LocaltimeExcel ExcelLocaltime 
+                col2int int2col sheetRef xls2csv);
+$VERSION=0.06;
 #my $sNUMEXP = '^[+-]?\d+(\.\d+)?$';
-my $sNUMEXP = '(^[+-]?\d+(\.\d+)?$)|(^[+-]?\d\.*(\d+)[eE][+-](\d+))$';
+#my $sNUMEXP = '(^[+-]?\d+(\.\d+)?$)|(^[+-]?\d\.*(\d+)[eE][+-](\d+))$';
+my $sNUMEXP = '(^[+-]?\d+(\.\d+)?$)|(^[+-]?\d+\.?(\d*)[eE][+-](\d+))$';
 
 #ProtoTypes
 sub ExcelFmt($$;$$);
 sub LocaltimeExcel($$$$$$;$$);
 sub ExcelLocaltime($;$);
 sub AddComma($);
-sub MakeBun($$);
+sub MakeBun($$;$);
 sub MakeE($$);
 sub LeapYear($);
 
@@ -151,8 +153,8 @@ sub ExcelFmt($$;$$) {
         }
         elsif($sWk eq '\\') {
             if($iQ == 1) {
-	    }
-	    else {
+        }
+        else {
                 $iQ = 1;
                 $i++;
                 next;
@@ -501,6 +503,7 @@ sub ExcelFmt($$;$$) {
             my $iTtl=0;
             my $iE=0;
             my $iP=0;
+            my $iInt = 0;
             my $iAftP=undef;
             foreach my $sItem (split //, $sNumFmt) {
                 if($sItem eq '.') {
@@ -513,10 +516,12 @@ sub ExcelFmt($$;$$) {
                 elsif($sItem eq '0') {
                     $iTtl++;
                     $iAftP++ if($iP);
+                    $iInt = 1;
                 }
                 elsif($sItem eq '#') {
                     #$iTtl++;
                     $iAftP++ if($iP);
+                    $iInt = 1;
                 }
                 elsif($sItem eq '?') {
                     #$iTtl++;
@@ -557,7 +562,7 @@ sub ExcelFmt($$;$$) {
                 }
                 elsif($rItem->[0] =~ /\//) {
                     substr($sFmtRes, $rItem->[1], $rItem->[2]) = 
-                        MakeBun($rItem->[0], $iData);
+                        MakeBun($rItem->[0], $iData, $iInt);
                 }
                 elsif($rItem->[0] eq '.') {
                     $iLen--;
@@ -654,14 +659,21 @@ sub AddComma($) {
 #------------------------------------------------------------------------------
 # MakeBun (for Spreadsheet::ParseExcel::Utility)
 #------------------------------------------------------------------------------
-sub MakeBun($$) {
-    my($sFmt, $iData) = @_;
+sub MakeBun($$;$) {
+    my($sFmt, $iData, $iFlg) = @_;
     my $iBunbo;
     my $iShou;
 
 #1. Init
-    $iShou = $iData - int($iData);
-    return '' if($iShou == 0);
+#print "FLG: $iFlg\n";
+    if($iFlg) {
+        $iShou = $iData - int($iData);
+        return '' if($iShou == 0);
+    }
+    else {
+        $iShou = $iData;
+    }
+    $iShou = abs($iShou);
     my $sSWk;
 
 #2.Calc BUNBO
@@ -832,6 +844,182 @@ sub ExcelLocaltime($;$)
     
   return ($iSec, $iMin, $iHour, $iDay, $iMon-1, $iYear, $iwDay, $iMSec);
 }
+# -----------------------------------------------------------------------------
+# col2int (for Spreadsheet::ParseExcel::Utility)
+#------------------------------------------------------------------------------
+# converts a excel row letter into an int for use in an array
+sub col2int {
+    my $result = 0 ;
+    my $str = shift ;
+   my $incr = 0 ;
+
+    for(my $i = length($str) ; $i > 0 ; $i--) {
+        my $char = substr( $str, $i-1) ;
+        my $curr += ord(lc($char)) - ord('a') + 1;
+        $curr *= $incr if( $incr) ;
+        $result += $curr ;
+        $incr += 26 ;
+    }
+    # this is one out as we range 0..x-1 not 1..x
+    $result-- ;
+
+    return $result ;
+}
+# -----------------------------------------------------------------------------
+# int2col (for Spreadsheet::ParseExcel::Utility)
+#------------------------------------------------------------------------------
+### int2col
+# convert a column number into column letters
+# @note this is quite a brute force coarse method
+#   does not manage values over 701 (ZZ)
+# @arg number, to convert
+# @returns string, column name
+#
+sub int2col {
+   my $out = "" ;
+   my $val = shift ;
+   
+   do {
+      $out .= chr(( $val % 26) + ord('A')) ;
+      $val = int( $val / 26) - 1 ;
+   } while( $val >= 0) ;
+   
+   return reverse $out ;
+}
+# -----------------------------------------------------------------------------
+# sheetRef (for Spreadsheet::ParseExcel::Utility)
+#------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
+### sheetRef
+# convert an excel letter-number address into a useful array address
+# @note that also Excel uses X-Y notation, we normally use Y-X in arrays
+# @args $str, excel coord eg. A2
+# @returns an array - 2 elements - column, row, or undefined
+#
+sub sheetRef {
+    my $str = shift ;
+    my @ret ;
+
+    $str =~ m/^(\D+)(\d+)$/ ;
+
+    if( $1 && $2) {
+        push( @ret, $2 -1, col2int($1)) ;
+    }
+    if( $ret[0] < 0) {
+        undef @ret ;
+    }
+
+    return @ret ;
+}
+# -----------------------------------------------------------------------------
+# xls2csv (for Spreadsheet::ParseExcel::Utility)
+#------------------------------------------------------------------------------
+### xls2csv
+# convert a chunk of an excel file into csv text chunk
+# @args $param, sheet-colrow:colrow (1-A1:B2 or A1:B2 for sheet 1
+# @args $rotate, 0 or 1 decides if output should be rotated or not
+# @returns string containing a chunk of csv
+#
+sub xls2csv {
+   my ($filename, $regions, $rotate) = @_ ;
+   my $sheet = 0 ;
+   my $output = "" ;   
+   
+   # extract any sheet number from the region string
+   $regions =~ m/^(\d+)-(.*)/ ;
+
+   if( $2) {
+      $sheet = $1 - 1 ;
+      $regions = $2 ;
+    }
+
+    # now extract the start and end regions
+    $regions =~ m/(.*):(.*)/ ;
+
+    if( !$1 || !$2) {
+        print STDERR "Bad Params";
+        return "" ;
+    }
+
+   my @start = sheetRef( $1) ;
+   my @end = sheetRef( $2) ;
+   if( !@start) {
+        print STDERR "Bad coorinates - $1";
+        return "" ;
+   }
+   if( !@end) {
+        print STDERR "Bad coorinates - $2";
+        return "" ;
+   }
+   
+   if( $start[1] > $end[1]) {
+        print STDERR "Bad COLUMN ordering\n";
+        print STDERR "Start column " . int2col($start[1]);
+        print STDERR " after end column " . int2col($end[1]) . "\n";
+        return "" ;
+   }
+   if( $start[0] > $end[0]) {
+        print STDERR "Bad ROW ordering\n";
+        print STDERR "Start row " . ($start[0] + 1);
+        print STDERR " after end row " . ($end[0] + 1) . "\n";
+        exit ;
+   }
+   
+   # start the excel object now
+   my $oExcel = new Spreadsheet::ParseExcel ;
+   my $oBook = $oExcel->Parse( $filename) ;
+   # open the sheet
+   my $oWkS = $oBook->{Worksheet}[ $sheet] ;
+
+   # now check that the region exists in the file
+   # if not trucate to the possible region
+   # output a warning msg
+   if( $start[1] < $oWkS->{MinCol}) {
+        print STDERR int2col( $start[1]) . " < min col " . int2col( $oWkS->{MinCol}) . " Reseting\n";
+        $start[1] = $oWkS->{MinCol} ;
+   }
+   if( $end[1] > $oWkS->{MaxCol}) {
+        print STDERR int2col( $end[1]) . " > max col " . int2col( $oWkS->{MaxCol}) . " Reseting\n" ;
+        $end[1] = $oWkS->{MaxCol} ;
+   }
+   if( $start[0] < $oWkS->{MinRow}) {
+        print STDERR "" . ($start[0] + 1) . " < min row " . ($oWkS->{MinRow} + 1) . " Reseting\n";
+        $start[0] = $oWkS->{MinCol} ;
+   }
+   if( $end[0] > $oWkS->{MaxRow}) {
+        print STDERR "" . ($end[0] + 1) . " > max row " . ($oWkS->{MaxRow} + 1) . " Reseting\n";
+        $end[0] = $oWkS->{MaxRow} ;
+   
+   }
+
+   my $x1 = $start[1] ;
+   my $y1 = $start[0] ;
+   my $x2 = $end[1] ;
+   my $y2 = $end[0] ;
+
+    if( !$rotate) {       
+    for( my $y = $y1 ; $y <= $y2 ; $y++) {
+       for( my $x = $x1 ; $x <= $x2 ; $x++) {
+          my $cell = $oWkS->{Cells}[$y][$x] ;
+          $output .=  $cell->Value ;
+          $output .= "," if( $x != $x2) ;
+       }
+       $output .= "\n" ;
+    }
+     } else {
+    for( my $x = $x1 ; $x <= $x2 ; $x++) {
+       for( my $y = $y1 ; $y <= $y2 ; $y++) {
+          my $cell = $oWkS->{Cells}[$y][$x] ;
+          $output .=  $cell->Value ;
+          $output .= "," if( $y != $y2) ;
+       }
+       $output .= "\n" ;
+    }
+     }
+   
+   return $output ;
+}
+
 1;
 __END__
 
@@ -904,7 +1092,44 @@ I<$iSec>, I<$iMin>, I<$iHour>, I<$iDay>, I<$iMon>, I<$iYear> are same as localti
 If I<$flg1904> is true, this functions assumes that epoch is 1904.
 I<$iExTime> is a time of Excel. 
 
-=head2 AUTHOR
+=head2 col2int
+
+I<$iInt> = col2int($sCol);
+
+converts a excel row letter into an int for use in an array
+
+This function was contributed by Kevin Mulholland.
+
+=head2 int2col
+
+I<$sCol> = int2col($iRow);
+
+convert a column number into column letters
+NOET: This is quite a brute force coarse method does not manage values over 701 (ZZ)
+
+This function was contributed by Kevin Mulholland.
+
+=head2 sheetRef
+
+(I<$iRow>, I<$iCol>) = sheetRef($sStr);
+
+convert an excel letter-number address into a useful array address
+NOTE: That also Excel uses X-Y notation, we normally use Y-X in arrays
+$sStr, excel coord (eg. A2).
+
+This function was contributed by Kevin Mulholland.
+
+=head2 xls2csv
+
+$sCsvTxt = xls2csv($sFileName, $sRegion, $iRotate);
+
+convert a chunk of an excel file into csv text chunk
+$sRegions = "sheet-colrow:colrow" (ex. '1-A1:B2' means 'A1:B2' for sheet 1)
+$iRotate  = 0 or 1 (output should be rotated or not)
+
+This function was contributed by Kevin Mulholland.
+
+=head1 AUTHOR
 
 Kawai Takanori (Hippo2000) kwitknr@cpan.org
 
